#!/usr/bin/env python3
#-*- coding: utf-8 -*-
#
# Privacy Indicator - Unity appindicator to switch privacy settings
#                     http://www.florian-diesch.de/software/indicator-privacy/
#
# Copyright (C) 2013 Florian Diesch <devel@florian-diesch.de>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import glob, sys
from setuptools import setup, find_packages

import  _meta

def read_from_file(path):
    with open(path) as input:
        return input.read()

setup(
    name = 'indicator-privacy',
    version = _meta.VERSION,
    packages = find_packages(),
    include_package_data = True,
    maintainer = _meta.AUTHOR_NAME,
    maintainer_email = _meta.AUTHOR_EMAIL,
    author = _meta.AUTHOR_NAME,
    author_email =  _meta.AUTHOR_EMAIL,
    description = _meta.DESC,
    long_description = read_from_file('README.txt'),
    data_files=[
        ('/etc/xdg/autostart',
        glob.glob('build/share/applications/*.desktop')),
        ('/usr/share/glib-2.0/schemas',
        glob.glob('data/schemas/*.xml')),
        ("share/icons/ubuntu-mono-light/status/22",
        glob.glob("data/icons/ubuntu-mono-light/status/22/*.svg")),
        ("share/icons/ubuntu-mono-light/status/24",
        glob.glob("data/icons/ubuntu-mono-light/status/24/*.svg")),
        ("share/icons/ubuntu-mono-light/status/64",
        glob.glob("data/icons/ubuntu-mono-light/status/64/*.svg")),
        ("share/icons/ubuntu-mono-light/status/16",
        glob.glob("data/icons/ubuntu-mono-light/status/16/*.svg")),
        ("share/icons/ubuntu-mono-light/status/32",
        glob.glob("data/icons/ubuntu-mono-light/status/32/*.svg")),
        ("share/icons/ubuntu-mono-light/status/48",
        glob.glob("data/icons/ubuntu-mono-light/status/48/*.svg")),
        ("share/icons/hicolor/22x22",
        glob.glob("data/icons/hicolor/22x22/*.svg")),
        ("share/icons/hicolor/22x22/apps",
        glob.glob("data/icons/hicolor/22x22/apps/*.svg")),
        ("share/icons/hicolor/24x24",
        glob.glob("data/icons/hicolor/24x24/*.svg")),
        ("share/icons/hicolor/24x24/apps",
        glob.glob("data/icons/hicolor/24x24/apps/*.svg")),
        ("share/icons/hicolor/64x64",
        glob.glob("data/icons/hicolor/64x64/*.svg")),
        ("share/icons/hicolor/64x64/apps",
        glob.glob("data/icons/hicolor/64x64/apps/*.svg")),
        ("share/icons/hicolor/32x32",
        glob.glob("data/icons/hicolor/32x32/*.svg")),
        ("share/icons/hicolor/32x32/apps",
        glob.glob("data/icons/hicolor/32x32/apps/*.svg")),
        ("share/icons/hicolor/scalable",
        glob.glob("data/icons/hicolor/scalable/*.svg")),
        ("share/icons/hicolor/scalable/apps",
        glob.glob("data/icons/hicolor/scalable/apps/*.svg")),
        ("share/icons/hicolor/48x48",
        glob.glob("data/icons/hicolor/48x48/*.svg")),
        ("share/icons/hicolor/48x48/apps",
        glob.glob("data/icons/hicolor/48x48/apps/*.svg")),
        ("share/icons/hicolor/16x16",
        glob.glob("data/icons/hicolor/16x16/*.svg")),
        ("share/icons/hicolor/16x16/apps",
        glob.glob("data/icons/hicolor/16x16/apps/*.svg")),
        ("share/icons/ubuntu-mono-dark",
        glob.glob("data/icons/ubuntu-mono-dark/*.svg")),
        ("share/icons/ubuntu-mono-dark/status",
        glob.glob("data/icons/ubuntu-mono-dark/status/*.svg")),
        ("share/icons/ubuntu-mono-dark/status/22",
        glob.glob("data/icons/ubuntu-mono-dark/status/22/*.svg")),
        ("share/icons/ubuntu-mono-dark/status/24",
        glob.glob("data/icons/ubuntu-mono-dark/status/24/*.svg")),
        ("share/icons/ubuntu-mono-dark/status/64",
        glob.glob("data/icons/ubuntu-mono-dark/status/64/*.svg")),
        ("share/icons/ubuntu-mono-dark/status/16",
        glob.glob("data/icons/ubuntu-mono-dark/status/16/*.svg")),
        ("share/icons/ubuntu-mono-dark/status/32",
        glob.glob("data/icons/ubuntu-mono-dark/status/32/*.svg")),
        ("share/icons/ubuntu-mono-dark/status/48",
        glob.glob("data/icons/ubuntu-mono-dark/status/48/*.svg")),
        ],
    entry_points = {
        'console_scripts': ['indicator-privacy=indicator_privacy:main'],
        },
    license = 'GPLv3',
    url = _meta.WEB_URL,
    download_url = _meta.WEB_URL,
    keywords = "Unity, Indicator, Privacy, Menu, Settings", 
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: X11 Applications',
        'Environment :: X11 Applications :: Gnome',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Natural Language :: German',
        'Natural Language :: Arabic',
        'Natural Language :: Chinese (Simplified)',
        'Natural Language :: Croatian',
        'Natural Language :: French',
        'Natural Language :: Hungarian',
        'Natural Language :: Malay',
        'Natural Language :: Spanish',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: Implementation :: CPython',
        'Topic :: Desktop Environment',
        'Topic :: Utilities',
        ],
    )
